##  Overview
In this migration guide, you can find examples showing how to transition from the [Fact Sheets REST API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%23%2FfactSheets "https://app.leanix.net/openapi-explorer/#/factSheets") to the GraphQL API. For each operation that you can perform on fact sheets through the API, we provide an example REST call and its equivalent GraphQL query or mutation.
For the REST implementation, the result of an operation may vary depending on the provided parameters. We illustrate requests for each specific parameter with examples, providing a clear path for a seamless migration.
In the following sections are examples for each documented endpoint within the [OpenAPI Explorer![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapp.leanix.net%2Fopenapi-explorer%2F%23%2FfactSheets%2FgetFactSheets "https://app.leanix.net/openapi-explorer/#/factSheets/getFactSheets").
